import { GameRecordCard, SpiralAbyss, GenshinUser, RealTimeNotes, Charcters, TravelerDiary, DailyRewards, Activities, RedeemCode, TCG, RoleCombat } from "../routes";
import { ClientCookieManager } from "./clientCookieManager";
import { Language } from "../constants/lang";
export interface ClientOptions {
    language: Language;
    cookieManager: ClientCookieManager;
    debug: boolean;
    cacheOptions: Partial<CacheOptions>;
}
interface CacheOptions {
    maxAge: number;
    maxSize: number;
}
export declare class Client {
    /**
     * @type {DailyRewards}
     * @description Daily rewards endpoint
     */
    dailyReward?: DailyRewards;
    /**
     * @type {GameRecordCard}
     * @description Game record card endpoint
     */
    gameRecordCard?: GameRecordCard;
    /**
     * @type {SpiralAbyss}
     * @description Spiral abyss endpoint
     */
    sprialAbyss?: SpiralAbyss;
    /**
     * @type {Activities}
     * @description Genshin activity endpoint
     */
    genshinActivity?: Activities;
    /**
     * @type {Charcters}
     * @description Genshin character endpoint
     */
    characters?: Charcters;
    /**
     * @type {GenshinUser}
     * @description Genshin user endpoint
     */
    genshinUser?: GenshinUser;
    /**
     * @type {RealTimeNotes}
     * @description Real time notes endpoint
     */
    realTimeNotes?: RealTimeNotes;
    /**
     * @type {TravelerDiary}
     * @description Traveler diary endpoint
     */
    travelDiary?: TravelerDiary;
    /**
     * @type {RedeemCode}
     * @description Redeem code endpoint
     */
    redeemCode?: RedeemCode;
    /**
     * @type {TCG}
     * @description TCG endpoint
     */
    tcg?: TCG;
    /**
     * @type {RoleCombat}
     * @description Imaginarium Theater(Role Combat) endpoint
     */
    roleCombat?: RoleCombat;
    private options;
    private logined;
    private cookieManager;
    /**
     * @param {ClientOptions} options - The options to use.
     */
    constructor(options?: Partial<ClientOptions>);
    login(ltuid: string, ltoken: string): Required<this>;
    addCookies(cookies: {
        ltuid: string;
        ltoken: string;
    }[]): void;
    isLogin(): this is Client & Required<this>;
    private initSweeper;
}
export {};
