/**
 * @description Cache of API responses.
 */
export type SweepFilterOptions<V = unknown> = (value: {
    value: V;
    timestamp: number;
    size: number;
}, key: string) => boolean;
export declare class ClientCache<V> extends Map<string, V> {
    private lifeMap;
    private maxSize?;
    constructor(cacheOptions: {
        maxSize?: number;
    });
    /**
     * @param {SweepFilterOptions<V>} fn
     * @description Sweep the cache based on the filter function.
     */
    sweep(fn: SweepFilterOptions<V>): void;
    /**
     * @param {string} key
     * @param {V} value
     * @description Set a new value to the cache.
     */
    set(key: string, value: V): this;
    get(key: string): V;
}
