interface cookie {
    ltuid: string;
    ltoken: string;
    key: number;
    cookie: string;
}
type CookieStore = Pick<cookie, "ltoken" | "ltuid"> & {
    cookie_token?: string;
};
export declare class ClientCookieManager {
    private cookie;
    constructor();
    /**
     * @description Get the amount of cookies.
     * @returns {number} - The amount of cookies.
     */
    get size(): number;
    setCookie(ltuid: string, ltoken: string): void;
    /**
     * @description Get the ltoken and ltuid for request.
     * @returns {cookie} - The ltoken and ltuid.
     */
    get(): cookie;
    /**
     * @param key - The key to remove.
     */
    delete(key: number): void;
    /**
     * @description Clear all cookies.
     */
    clear(): void;
    /**
     * @description Get all cookies.
     * @returns {cookie[]} - The cookies.
     */
    getAll(): cookie[];
    /**
     * @param {string} customProfile - The custom profile to get the cookie.
     * @description Get the ltoken and ltuid from browser cookie. (Install chrome-cookies-secure first)
     */
    getBrowserCookie(customProfile: string): Promise<CookieStore>;
}
export {};
