import { BaseRoute, FetchOptions, Options } from "./base";
import type { CharacterData, CharacterDetailsData, CharacterInfoData } from "../interface";
export type CharctersListFetchOptions = FetchOptions & {
    /**
     * @description The sort type of the character list
     * @property {number} 1 - Level Descending
     * @property {number} 5 - Level Ascending
     * @property {number} 2 - Rarity Descending
     * @property {number} 3 - Rarity Ascending
     * @property {number} 6 - Fetter Descending
     * @property {number} 7 - Fetter Ascending
     * @default undefined
     */
    sort_type?: number;
    /**
     * @description The element type of the character
     * @property {"Pyro" | "Hydro" | "Dendro" | "Electro" | "Anemo" | "Geo" | "Cryo"} elements - The element type of the character
     * @default undefined
     */
    elements?: ("Pyro" | "Hydro" | "Dendro" | "Electro" | "Anemo" | "Geo" | "Cryo")[];
    /**
     * @description The weapon type of the character
     * @property {number} 1 - Sword
     * @property {number} 11 - Claymore
     * @property {number} 12 - Bow
     * @property {number} 13 - Polearm
     * @property {number} 10 - Catalyst
     * @default undefined
     */
    weapon_type?: (1 | 12 | 10 | 13 | 11)[];
};
export declare class Charcters extends BaseRoute<CharacterData[]> {
    private readonly defaultOptions?;
    constructor(options?: Options);
    /**
     * @param {string} uid Genshin Impact UID
     */
    fetch(uid: string, options?: CharctersListFetchOptions): Promise<CharacterData[]>;
    /**
     * @param {number} characterId The avatar's id
     */
    fetchAvatarInfo(characterId: number, options?: FetchOptions): Promise<CharacterInfoData>;
    /**
     * @param {string} uid Genshin Impact UID
     * @param {number} characterId The avatar's id
     */
    fetchAvatarDetail(uid: string, characterId: number, options?: FetchOptions): Promise<CharacterDetailsData>;
}
