"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenshinUser = exports.Achievement = void 0;
const base_1 = require("./base");
const utils_1 = require("../utils");
class Achievement extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        });
        if (!(0, utils_1.basicValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie } = optionsToUse;
        const instance = new utils_1.RequestManager({
            language,
        });
        const res = await instance.post("achievement", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
exports.Achievement = Achievement;
class GenshinUser extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "achievement", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
        this.achievement = new Achievement(options);
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        }, utils_1.OptionType.UserInfoFetchOptions);
        if (!(0, utils_1.userInfoValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, avatar_list_type } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("index", {
            Cookie: cookie,
        }, {
            avatar_list_type: avatar_list_type ?? 1,
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
exports.GenshinUser = GenshinUser;
