"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.claimHistoryValidator = exports.getMonthValidator = exports.redeemValidator = exports.cardListValidator = exports.roleCombatValidator = exports.userInfoValidator = exports.characterDetailsValidator = exports.charctersListValidator = exports.spiralAbyssValidator = exports.basicValidator = void 0;
const zod_1 = require("zod");
const basicValidator = (key, options) => {
    if (typeof key === "string") {
        const schema = zod_1.z.object({
            key: zod_1.z.string(),
            options: zod_1.z.object({
                language: zod_1.z.string(),
                cookie: zod_1.z.string().min(1),
            }),
        });
        schema.parse({ key, options });
        return true;
    }
    if (typeof key === "number") {
        const schema = zod_1.z.object({
            key: zod_1.z.number(),
            options: zod_1.z.object({
                language: zod_1.z.string(),
                cookie: zod_1.z.string().min(1),
            }),
        });
        schema.parse({ key, options });
        return true;
    }
    return false;
};
exports.basicValidator = basicValidator;
const spiralAbyssValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            previous: zod_1.z.boolean().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.spiralAbyssValidator = spiralAbyssValidator;
const charctersListValidator = (uid, options) => {
    // "Pyro" | "Hydro" | "Dendro" | "Electro" | "Anemo" | "Geo" | "Cryo"
    const elements = zod_1.z.enum(["Pyro", "Hydro", "Dendro", "Electro", "Anemo", "Geo", "Cryo"]).array().optional();
    // 1 | 12 | 10 | 13 | 11
    const weapon_type = {
        Sword: 1,
        Claymore: 11,
        Bow: 12,
        Polearm: 13,
        Catalyst: 10,
    };
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            sort_type: zod_1.z.number().optional(),
            elements,
            weapon_type: zod_1.z.nativeEnum(weapon_type).array().optional(),
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.charctersListValidator = charctersListValidator;
const characterDetailsValidator = (uid, character_id, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        character_id: zod_1.z.number(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ uid, character_id, options });
    return true;
};
exports.characterDetailsValidator = characterDetailsValidator;
const userInfoValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            avatar_list_type: zod_1.z.number().optional(),
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.userInfoValidator = userInfoValidator;
const roleCombatValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            need_detail: zod_1.z.boolean().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.roleCombatValidator = roleCombatValidator;
const cardListValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            need_avatar: zod_1.z.boolean().optional(),
            need_action: zod_1.z.boolean().optional(),
            need_stats: zod_1.z.boolean().optional(),
            offset: zod_1.z.number().optional(),
            limit: zod_1.z.number().optional(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.cardListValidator = cardListValidator;
const redeemValidator = (code, options) => {
    const schema = zod_1.z.object({
        code: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            account_id: zod_1.z.string().min(1),
            cookie_token: zod_1.z.string().min(1),
            uid: zod_1.z.string(),
        }),
    });
    schema.parse({ code, options });
    return true;
};
exports.redeemValidator = redeemValidator;
const getMonthValidator = (uid, options) => {
    const schema = zod_1.z.object({
        uid: zod_1.z.string(),
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            month: zod_1.z.number(),
        }),
    });
    schema.parse({ uid, options });
    return true;
};
exports.getMonthValidator = getMonthValidator;
const claimHistoryValidator = (options) => {
    const schema = zod_1.z.object({
        options: zod_1.z.object({
            language: zod_1.z.string(),
            cookie: zod_1.z.string().min(1),
            page: zod_1.z.number().optional(),
        }),
    });
    schema.parse({ options });
    return true;
};
exports.claimHistoryValidator = claimHistoryValidator;
